# oceansguard/types.py
from __future__ import annotations


class UX:
    """
    OceansGuard の標準ログ出力インターフェース。
    """

    def __init__(self, verbose: bool = False) -> None:
        self.verbose = verbose

    def info(self, msg: str) -> None:
        print(f"[OceansGuard] {msg}")

    def warn(self, msg: str) -> None:
        print(f"[OceansGuard][WARN] {msg}")

    def debug(self, msg: str) -> None:
        if self.verbose:
            print(f"[OceansGuard][DEBUG] {msg}")
